diff --git a/indra/newview/skins/default/xui/en/notifications.xml b/indra/newview/skins/default/xui/en/notifications.xml
index 4c6a61adfd3efc46ca58fd76a489c59bb78c91cc..570a69256d88a4171b34d0a8c591a4ccc56e5426 100755
--- a/indra/newview/skins/default/xui/en/notifications.xml
+++ b/indra/newview/skins/default/xui/en/notifications.xml
@@ -343,6 +343,17 @@ Initialization with the Marketplace failed because of a system or network error.
         yestext="OK"/>
     </notification>
     
+    <notification
+        icon="OutboxStatus_Error"
+        name="MerchantUnprocessableEntity"
+        type="outbox">
+        We are unable to list this product. Usually this is caused by missing information in the listing description form. If you continue to see this error, try again later.
+        
+        <usetemplate
+        name="okbutton"
+        yestext="OK"/>
+    </notification>
+
     <notification
         icon="OutboxStatus_Error"
         name="MerchantListingFailed"
diff --git a/indra/newview/llmarketplacefunctions.cpp b/indra/newview/llmarketplacefunctions.cpp
index d292dd25e79686d7c3b2fa17f12dbdcf7ad8433b..ab50506a4f61faf5faf1076a34889034cd11b079 100755
--- a/indra/newview/llmarketplacefunctions.cpp
+++ b/indra/newview/llmarketplacefunctions.cpp
@@ -124,13 +124,20 @@ LLUUID getVersionFolderIfUnique(const LLUUID& folder_id)
 void log_SLM_warning(const std::string& request, U32 status, const std::string& reason, const std::string& code, const std::string& description)
 {
     LL_WARNS("SLM") << "SLM API : Responder to " << request << ". status : " << status << ", reason : " << reason << ", code : " << code << ", description : " << description << LL_ENDL;
-    // Prompt the user with the warning (so they know why things are failing)
-    LLSD subs;
-    subs["[ERROR_REASON]"] = reason;
-    // We do show long descriptions in the alert (unlikely to be readable). The description string will be in the log though.
-    subs["[ERROR_DESCRIPTION]"] = (description.length() <= 512 ? description : "");
-    LLNotificationsUtil::add("MerchantTransactionFailed", subs);
-    
+    if (status == 422)
+    {
+        // Unprocessable Entity : Special case that error as it is a frequent answer when trying to list an incomplete listing
+        LLNotificationsUtil::add("MerchantUnprocessableEntity");
+    }
+    else
+    {
+        // Prompt the user with the warning (so they know why things are failing)
+        LLSD subs;
+        subs["[ERROR_REASON]"] = reason;
+        // We do show long descriptions in the alert (unlikely to be readable). The description string will be in the log though.
+        subs["[ERROR_DESCRIPTION]"] = (description.length() <= 512 ? description : "");
+        LLNotificationsUtil::add("MerchantTransactionFailed", subs);
+    }
 }
 void log_SLM_infos(const std::string& request, U32 status, const std::string& body)
 {